<div style="background: linear-gradient(135deg, #667eea 0%, #764ba2 100%); 
            padding: 28px 32px; 
            border-radius: 14px; 
            color: white; 
            font-family: Arial, sans-serif;
            max-width: 800px;
            margin: 32px auto;">
    <h3 style="text-align: center; margin-top: 0; color: #63b3ed;">📊 Sample Data Visualization</h3>
    <div style="margin: 20px 0;">
        <div style="margin-bottom: 10px;">
            <span style="color: #a0aec0;">Sales (Jan-Mar 2024)</span>
            <div style="background: #1a202c; height: 30px; border-radius: 15px; position: relative; margin-top: 5px;">
                <div style="background: linear-gradient(90deg, #4299e1, #63b3ed); height: 100%; width: 75%; border-radius: 15px; display: flex; align-items: center; justify-content: center; font-weight: bold;">75%</div>
            </div>
        </div>
        <div style="margin-bottom: 10px;">
            <span style="color: #a0aec0;">Customer Satisfaction</span>
            <div style="background: #1a202c; height: 30px; border-radius: 15px; position: relative; margin-top: 5px;">
                <div style="background: linear-gradient(90deg, #48bb78, #68d391); height: 100%; width: 92%; border-radius: 15px; display: flex; align-items: center; justify-content: center; font-weight: bold;">92%</div>
            </div>
        </div>
        <div style="margin-bottom: 10px;">
            <span style="color: #a0aec0;">Market Share</span>
            <div style="background: #1a202c; height: 30px; border-radius: 15px; position: relative; margin-top: 5px;">
                <div style="background: linear-gradient(90deg, #ed8936, #f6ad55); height: 100%; width: 58%; border-radius: 15px; display: flex; align-items: center; justify-content: center; font-weight: bold;">58%</div>
            </div>
        </div>
    </div>
    <div style="text-align: center; margin-top: 20px; padding: 10px; background: rgba(99, 179, 237, 0.1); border-radius: 5px;">
        <small style="color: #a0aec0;">Generated by MCP Server with custom HTML</small>
    </div>
</div>
